==> green-core-1.76.1.tgz: package/components/text/text.component.js <==
import {
  __decorateClass
} from "../../chunks/chunk.QTSIPXV3.js";
import { property } from "lit/decorators.js";
import { html, unsafeStatic } from "lit/static-html.js";
import { tokens } from "../../tokens.style.js";
import { styleExpressionProperty } from "../../utils/decorators/style-expression-property.js";
import { gdsCustomElement } from "../../utils/helpers/custom-element-scoping.js";
import { GdsDiv } from "../div/div.component.js";
import { defaultStyles } from "./default-typography.styles.js";
import textStyles from "./text.style.js";
let GdsText = class extends GdsDiv {
  constructor() {
    super(...arguments);
    this.tag = "span";
  }
  render() {
    const TAG = unsafeStatic(encodeURI(this.tag));
    return html`<${TAG} tag><slot></slot></${TAG}>`;
  }
};
GdsText.styles = [tokens, defaultStyles, textStyles];
__decorateClass([
  property({ type: String })
], GdsText.prototype, "tag", 2);
__decorateClass([
  styleExpressionProperty({
    selector: "[tag]",
    styleTemplate: (_prop, values) => {
      const size = values[0];
      const styleSize = `font-size: var(--gds-text-size-${size});`;
      const styleLine = `line-height: var(--gds-text-line-height-${size});`;
      return styleSize + styleLine;
    }
  })
], GdsText.prototype, "font-size", 2);
__decorateClass([
  styleExpressionProperty({
    selector: "[tag]",
    valueTemplate: (v) => `var(--gds-text-weight-${v})`
  })
], GdsText.prototype, "font-weight", 2);
__decorateClass([
  styleExpressionProperty()
], GdsText.prototype, "text-transform", 2);
__decorateClass([
  styleExpressionProperty({
    selector: "[tag]"
  })
], GdsText.prototype, "text-decoration", 2);
__decorateClass([
  styleExpressionProperty({
    selector: "[tag]",
    styleTemplate: (_prop, values) => {
      return `overflow: hidden;
      text-overflow: ellipsis;
      display: -webkit-box;
      -webkit-line-clamp: ${values[0]};
      -webkit-box-orient: vertical;`;
    }
  })
], GdsText.prototype, "lines", 2);
GdsText = __decorateClass([
  gdsCustomElement("gds-text")
], GdsText);
export {
  GdsText
};

==> green-core-1.79.0.tgz: package/components/text/text.component.js <==
import {
  __decorateClass
} from "../../chunks/chunk.QTSIPXV3.js";
import { property } from "lit/decorators.js";
import { html, unsafeStatic } from "lit/static-html.js";
import { tokens } from "../../tokens.style.js";
import { styleExpressionProperty } from "../../utils/decorators/style-expression-property.js";
import { gdsCustomElement } from "../../utils/helpers/custom-element-scoping.js";
import { GdsDiv } from "../div/div.component.js";
import { defaultStyles } from "./default-typography.styles.js";
import textStyles from "./text.style.js";
let GdsText = class extends GdsDiv {
  constructor() {
    super(...arguments);
    this.tag = "span";
  }
  render() {
    const TAG = unsafeStatic(encodeURI(this.tag));
    return html`<${TAG} tag><slot></slot></${TAG}>`;
  }
};
GdsText.styles = [tokens, defaultStyles, textStyles];
__decorateClass([
  property({ type: String })
], GdsText.prototype, "tag", 2);
__decorateClass([
  styleExpressionProperty({
    selector: "[tag]",
    styleTemplate: (_prop, values) => {
      const size = values[0];
      const styleSize = `font-size: var(--gds-sys-text-size-${size});`;
      const styleLine = `line-height: var(--gds-sys-text-line-height-${size});`;
      return styleSize + styleLine;
    }
  })
], GdsText.prototype, "font-size", 2);
__decorateClass([
  styleExpressionProperty({
    selector: "[tag]",
    valueTemplate: (v) => `var(--gds-sys-text-weight-${v})`
  })
], GdsText.prototype, "font-weight", 2);
__decorateClass([
  styleExpressionProperty()
], GdsText.prototype, "text-transform", 2);
__decorateClass([
  styleExpressionProperty({
    selector: "[tag]"
  })
], GdsText.prototype, "text-decoration", 2);
__decorateClass([
  styleExpressionProperty({
    selector: "[tag]",
    styleTemplate: (_prop, values) => {
      return `overflow: hidden;
      text-overflow: ellipsis;
      display: -webkit-box;
      -webkit-line-clamp: ${values[0]};
      -webkit-box-orient: vertical;`;
    }
  })
], GdsText.prototype, "lines", 2);
GdsText = __decorateClass([
  gdsCustomElement("gds-text")
], GdsText);
export {
  GdsText
};
